==> monaco-vscode-user-data-sync-service-override-4.5.0.tgz: package/vscode/src/vs/platform/userDataSync/common/userDataSyncEnablementService.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Emitter } from 'vscode/vscode/vs/base/common/event';
import { Disposable, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import { isWeb } from 'vscode/vscode/vs/base/common/platform';
import { IEnvironmentService } from 'vscode/vscode/vs/platform/environment/common/environment.service';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { ITelemetryService } from 'vscode/vscode/vs/platform/telemetry/common/telemetry.service';
import { getEnablementKey, ALL_SYNC_RESOURCES } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';
import { IUserDataSyncStoreManagementService } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync.service';

const enablementKey = 'sync.enable';
let UserDataSyncEnablementService$1 = class UserDataSyncEnablementService extends Disposable {
    constructor(storageService, telemetryService, environmentService, userDataSyncStoreManagementService) {
        super();
        this.storageService = storageService;
        this.telemetryService = telemetryService;
        this.environmentService = environmentService;
        this.userDataSyncStoreManagementService = userDataSyncStoreManagementService;
        this._onDidChangeEnablement = ( new Emitter());
        this.onDidChangeEnablement = this._onDidChangeEnablement.event;
        this._onDidChangeResourceEnablement = ( new Emitter());
        this.onDidChangeResourceEnablement = this._onDidChangeResourceEnablement.event;
        this._register(storageService.onDidChangeValue(-1 , undefined, this._register(( new DisposableStore())))(e => this.onDidStorageChange(e)));
    }
    isEnabled() {
        switch (this.environmentService.sync) {
            case 'on':
                return true;
            case 'off':
                return false;
        }
        return this.storageService.getBoolean(enablementKey, -1 , false);
    }
    canToggleEnablement() {
        return this.userDataSyncStoreManagementService.userDataSyncStore !== undefined && this.environmentService.sync === undefined;
    }
    setEnablement(enabled) {
        if (enabled && !this.canToggleEnablement()) {
            return;
        }
        this.telemetryService.publicLog2(enablementKey, { enabled });
        this.storageService.store(enablementKey, enabled, -1 , 1 );
    }
    isResourceEnabled(resource) {
        return this.storageService.getBoolean(getEnablementKey(resource), -1 , true);
    }
    setResourceEnablement(resource, enabled) {
        if (this.isResourceEnabled(resource) !== enabled) {
            const resourceEnablementKey = getEnablementKey(resource);
            this.storeResourceEnablement(resourceEnablementKey, enabled);
        }
    }
    getResourceSyncStateVersion(resource) {
        return undefined;
    }
    storeResourceEnablement(resourceEnablementKey, enabled) {
        this.storageService.store(resourceEnablementKey, enabled, -1 , isWeb ? 0  : 1 );
    }
    onDidStorageChange(storageChangeEvent) {
        if (enablementKey === storageChangeEvent.key) {
            this._onDidChangeEnablement.fire(this.isEnabled());
            return;
        }
        const resourceKey = ALL_SYNC_RESOURCES.filter(resourceKey => getEnablementKey(resourceKey) === storageChangeEvent.key)[0];
        if (resourceKey) {
            this._onDidChangeResourceEnablement.fire([resourceKey, this.isResourceEnabled(resourceKey)]);
            return;
        }
    }
};
UserDataSyncEnablementService$1 = ( __decorate([
    ( __param(0, IStorageService)),
    ( __param(1, ITelemetryService)),
    ( __param(2, IEnvironmentService)),
    ( __param(3, IUserDataSyncStoreManagementService))
], UserDataSyncEnablementService$1));

export { UserDataSyncEnablementService$1 as UserDataSyncEnablementService };

==> monaco-vscode-user-data-sync-service-override-9.0.2.tgz: package/vscode/src/vs/platform/userDataSync/common/userDataSyncEnablementService.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Emitter } from 'vscode/vscode/vs/base/common/event';
import { Disposable, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import { isWeb } from 'vscode/vscode/vs/base/common/platform';
import { IEnvironmentService } from 'vscode/vscode/vs/platform/environment/common/environment.service';
import { StorageScope, StorageTarget } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { ITelemetryService } from 'vscode/vscode/vs/platform/telemetry/common/telemetry.service';
import { getEnablementKey, ALL_SYNC_RESOURCES } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';
import { IUserDataSyncStoreManagementService } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync.service';

const enablementKey = 'sync.enable';
let UserDataSyncEnablementService$1 = class UserDataSyncEnablementService extends Disposable {
    constructor(storageService, telemetryService, environmentService, userDataSyncStoreManagementService) {
        super();
        this.storageService = storageService;
        this.telemetryService = telemetryService;
        this.environmentService = environmentService;
        this.userDataSyncStoreManagementService = userDataSyncStoreManagementService;
        this._onDidChangeEnablement = ( new Emitter());
        this.onDidChangeEnablement = this._onDidChangeEnablement.event;
        this._onDidChangeResourceEnablement = ( new Emitter());
        this.onDidChangeResourceEnablement = this._onDidChangeResourceEnablement.event;
        this._register(storageService.onDidChangeValue(StorageScope.APPLICATION, undefined, this._register(( new DisposableStore())))(e => this.onDidStorageChange(e)));
    }
    isEnabled() {
        switch (this.environmentService.sync) {
            case 'on':
                return true;
            case 'off':
                return false;
        }
        return this.storageService.getBoolean(enablementKey, StorageScope.APPLICATION, false);
    }
    canToggleEnablement() {
        return this.userDataSyncStoreManagementService.userDataSyncStore !== undefined && this.environmentService.sync === undefined;
    }
    setEnablement(enabled) {
        if (enabled && !this.canToggleEnablement()) {
            return;
        }
        this.telemetryService.publicLog2(enablementKey, { enabled });
        this.storageService.store(enablementKey, enabled, StorageScope.APPLICATION, StorageTarget.MACHINE);
    }
    isResourceEnabled(resource) {
        return this.storageService.getBoolean(getEnablementKey(resource), StorageScope.APPLICATION, true);
    }
    setResourceEnablement(resource, enabled) {
        if (this.isResourceEnabled(resource) !== enabled) {
            const resourceEnablementKey = getEnablementKey(resource);
            this.storeResourceEnablement(resourceEnablementKey, enabled);
        }
    }
    getResourceSyncStateVersion(resource) {
        return undefined;
    }
    storeResourceEnablement(resourceEnablementKey, enabled) {
        this.storageService.store(resourceEnablementKey, enabled, StorageScope.APPLICATION, isWeb ? StorageTarget.USER  : StorageTarget.MACHINE);
    }
    onDidStorageChange(storageChangeEvent) {
        if (enablementKey === storageChangeEvent.key) {
            this._onDidChangeEnablement.fire(this.isEnabled());
            return;
        }
        const resourceKey = ALL_SYNC_RESOURCES.filter(resourceKey => getEnablementKey(resourceKey) === storageChangeEvent.key)[0];
        if (resourceKey) {
            this._onDidChangeResourceEnablement.fire([resourceKey, this.isResourceEnabled(resourceKey)]);
            return;
        }
    }
};
UserDataSyncEnablementService$1 = ( __decorate([
    ( __param(0, IStorageService)),
    ( __param(1, ITelemetryService)),
    ( __param(2, IEnvironmentService)),
    ( __param(3, IUserDataSyncStoreManagementService))
], UserDataSyncEnablementService$1));

export { UserDataSyncEnablementService$1 as UserDataSyncEnablementService };
